@@ -3,6 +3,8 @@
  * Copyright (C) 2019 Gwenhael Goavec-Merou <gwenhael.goavec-merou@trabucayre.com>
  */
 
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -1048,7 +1050,7 @@ void Lattice::displayReadReg(uint64_t dev)
 	uint8_t err;
 	printf("displayReadReg\n");
 	if (dev & 1<<0) printf("\tTRAN Mode\n");
-	printf("\tConfig Target Selection : %llx\n", (dev >> 1) & 0x07);
+	printf("\tConfig Target Selection : %" PRIx64 "\n", (dev >> 1) & 0x07);
 	if (dev & 1<<4) printf("\tJTAG Active\n");
 	if (dev & 1<<5) printf("\tPWD Protect\n");
 	if (dev & 1<<6) printf("\tOTP\n");
